<?php

namespace Litecms\TicketInputing\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Litecms\TicketInputing\Http\Requests\TicketInputingRequest;
use Litecms\TicketInputing\Interfaces\TicketInputingRepositoryInterface;
use Litecms\TicketInputing\Models\TicketInputing;

/**
 * Resource controller class for ticket_inputing.
 */
class TicketInputingResourceController extends BaseController
{

    /**
     * Initialize ticket_inputing resource controller.
     *
     * @param type TicketInputingRepositoryInterface $ticket_inputing
     *
     * @return null
     */
    public function __construct(TicketInputingRepositoryInterface $ticket_inputing)
    {
        parent::__construct();
        $this->repository = $ticket_inputing;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Litecms\TicketInputing\Repositories\Criteria\TicketInputingResourceCriteria::class);
    }

    /**
     * Display a list of ticket_inputing.
     *
     * @return Response
     */
    public function index(TicketInputingRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Litecms\TicketInputing\Repositories\Presenter\TicketInputingPresenter::class)
                ->$function();
        }

        $ticket_inputings = $this->repository->paginate();

        return $this->response->title(trans('ticket_inputing::ticket_inputing.names'))
            ->view('ticket_inputing::ticket_inputing.index', true)
            ->data(compact('ticket_inputings'))
            ->output();
    }

    /**
     * Display ticket_inputing.
     *
     * @param Request $request
     * @param Model   $ticket_inputing
     *
     * @return Response
     */
    public function show(TicketInputingRequest $request, TicketInputing $ticket_inputing)
    {

        if ($ticket_inputing->exists) {
            $view = 'ticket_inputing::ticket_inputing.show';
        } else {
            $view = 'ticket_inputing::ticket_inputing.new';
        }

        return $this->response->title(trans('app.view') . ' ' . trans('ticket_inputing::ticket_inputing.name'))
            ->data(compact('ticket_inputing'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new ticket_inputing.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(TicketInputingRequest $request)
    {

        $ticket_inputing = $this->repository->newInstance([]);
        return $this->response->title(trans('app.new') . ' ' . trans('ticket_inputing::ticket_inputing.name')) 
            ->view('ticket_inputing::ticket_inputing.create', true) 
            ->data(compact('ticket_inputing'))
            ->output();
    }

    /**
     * Create new ticket_inputing.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(TicketInputingRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $ticket_inputing                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('ticket_inputing::ticket_inputing.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('ticket_inputing/ticket_inputing/' . $ticket_inputing->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/ticket_inputing/ticket_inputing'))
                ->redirect();
        }

    }

    /**
     * Show ticket_inputing for editing.
     *
     * @param Request $request
     * @param Model   $ticket_inputing
     *
     * @return Response
     */
    public function edit(TicketInputingRequest $request, TicketInputing $ticket_inputing)
    {
        return $this->response->title(trans('app.edit') . ' ' . trans('ticket_inputing::ticket_inputing.name'))
            ->view('ticket_inputing::ticket_inputing.edit', true)
            ->data(compact('ticket_inputing'))
            ->output();
    }

    /**
     * Update the ticket_inputing.
     *
     * @param Request $request
     * @param Model   $ticket_inputing
     *
     * @return Response
     */
    public function update(TicketInputingRequest $request, TicketInputing $ticket_inputing)
    {
        try {
            $attributes = $request->all();

            $ticket_inputing->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('ticket_inputing::ticket_inputing.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('ticket_inputing/ticket_inputing/' . $ticket_inputing->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('ticket_inputing/ticket_inputing/' . $ticket_inputing->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the ticket_inputing.
     *
     * @param Model   $ticket_inputing
     *
     * @return Response
     */
    public function destroy(TicketInputingRequest $request, TicketInputing $ticket_inputing)
    {
        try {

            $ticket_inputing->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('ticket_inputing::ticket_inputing.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('ticket_inputing/ticket_inputing/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('ticket_inputing/ticket_inputing/' . $ticket_inputing->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple ticket_inputing.
     *
     * @param Model   $ticket_inputing
     *
     * @return Response
     */
    public function delete(TicketInputingRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('ticket_inputing::ticket_inputing.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('ticket_inputing/ticket_inputing'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/ticket_inputing/ticket_inputing'))
                ->redirect();
        }

    }

    /**
     * Restore deleted ticket_inputings.
     *
     * @param Model   $ticket_inputing
     *
     * @return Response
     */
    public function restore(TicketInputingRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('ticket_inputing::ticket_inputing.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/ticket_inputing/ticket_inputing'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/ticket_inputing/ticket_inputing/'))
                ->redirect();
        }

    }

}
