<?php

namespace Litecms\TicketInputing\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\TicketInputing\Models\TicketInputing;

class TicketInputingPolicy
{

    /**
     * Determine if the given user can view the ticket_inputing.
     *
     * @param UserPolicy $user
     * @param TicketInputing $ticket_inputing
     *
     * @return bool
     */
    public function view(UserPolicy $user, TicketInputing $ticket_inputing)
    {
        if ($user->canDo('ticket_inputing.ticket_inputing.view') && $user->isAdmin()) {
            return true;
        }

        return $ticket_inputing->user_id == user_id() && $ticket_inputing->user_type == user_type();
    }

    /**
     * Determine if the given user can create a ticket_inputing.
     *
     * @param UserPolicy $user
     * @param TicketInputing $ticket_inputing
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('ticket_inputing.ticket_inputing.create');
    }

    /**
     * Determine if the given user can update the given ticket_inputing.
     *
     * @param UserPolicy $user
     * @param TicketInputing $ticket_inputing
     *
     * @return bool
     */
    public function update(UserPolicy $user, TicketInputing $ticket_inputing)
    {
        if ($user->canDo('ticket_inputing.ticket_inputing.edit') && $user->isAdmin()) {
            return true;
        }

        return $ticket_inputing->user_id == user_id() && $ticket_inputing->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given ticket_inputing.
     *
     * @param UserPolicy $user
     * @param TicketInputing $ticket_inputing
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, TicketInputing $ticket_inputing)
    {
        return $ticket_inputing->user_id == user_id() && $ticket_inputing->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given ticket_inputing.
     *
     * @param UserPolicy $user
     * @param TicketInputing $ticket_inputing
     *
     * @return bool
     */
    public function verify(UserPolicy $user, TicketInputing $ticket_inputing)
    {
        if ($user->canDo('ticket_inputing.ticket_inputing.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given ticket_inputing.
     *
     * @param UserPolicy $user
     * @param TicketInputing $ticket_inputing
     *
     * @return bool
     */
    public function approve(UserPolicy $user, TicketInputing $ticket_inputing)
    {
        if ($user->canDo('ticket_inputing.ticket_inputing.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
