<?php

namespace Litecms\TicketInputing\Providers;

use Illuminate\Support\ServiceProvider;

class TicketInputingServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'ticket_inputing');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'ticket_inputing');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('litecms.ticket_inputing', function ($app) {
            return $this->app->make('Litecms\TicketInputing\TicketInputing');
        });

                // Bind TicketInputing to repository
        $this->app->bind(
            'Litecms\TicketInputing\Interfaces\TicketInputingRepositoryInterface',
            \Litecms\TicketInputing\Repositories\Eloquent\TicketInputingRepository::class
        );

        $this->app->register(\Litecms\TicketInputing\Providers\AuthServiceProvider::class);
                $this->app->register(\Litecms\TicketInputing\Providers\EventServiceProvider::class);
        
        $this->app->register(\Litecms\TicketInputing\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litecms.ticket_inputing'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('litecms/ticket_inputing.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/ticket_inputing')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/ticket_inputing')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
